@@ -303,7 +303,7 @@ class Environment extends Base {
     this.command = this.options.command;
 
     this.runLoop = new GroupedQueue(Environment.queues, false);
-    this.sharedFs = memFs.create();
+    this.sharedFs = this.options.sharedFs || memFs.create();
 
     // Each composed generator might set listeners on these shared resources. Let's make sure
     // Node won't complain about event listeners leaks.
@@ -331,7 +331,7 @@ class Environment extends Base {
 
     this.repository = new YeomanRepository({
       repositoryPath: this.options.yeomanRepository,
-      arboristRegister: this.options.arboristRegister
+      arboristRegistry: this.options.arboristRegistry
     });
 
     if (!this.options.experimental) {
@@ -551,6 +551,30 @@ class Environment extends Base {
     return this.store.getGeneratorsMeta();
   }
 
+  /**
+   * Returns stored generators meta
+   * @param {string} namespace
+   * @return {any}
+   */
+  getGeneratorMeta(namespace) {
+    const meta = this.store.getMeta(namespace) || this.store.getMeta(this.alias(namespace));
+    if (!meta) {
+      return;
+    }
+
+    // eslint-disable-next-line node/no-unsupported-features/es-syntax
+    const importModule = async () => import(meta.resolved);
+    const instantiate = async (args, options) => this.instantiate(await this._findGeneratorClass(await meta.importGenerator()), args, options);
+    const instantiateHelp = async () => instantiate([], {help: true});
+    const newMeta = {
+      ...meta,
+      importModule,
+      instantiate,
+      instantiateHelp
+    };
+    return newMeta;
+  }
+
   /**
    * Get registered generators names
    *
@@ -679,11 +703,10 @@ class Environment extends Base {
    * @param  {Object} Generator - Object containing the class.
    * @return {Function} Generator's constructor.
    */
-  _findGeneratorClass(Generator) {
+  _findGeneratorClass(Generator, meta = Generator) {
     if (!Generator) {
       return Generator;
     }
-    let meta = Generator;
     if (Array.isArray(Generator)) {
       meta = Generator[1];
       Generator = Generator[0];
@@ -1058,6 +1081,7 @@ class Environment extends Base {
 
       this.runLoop.on('error', error => {
         this.emit('error', error);
+        this.adapter.close();
       });
 
       this.runLoop.on('paused', () => {
